@@ -29,6 +29,7 @@ from . import (
     dto,
     exceptions,
     health,
+    http,
     log,
     openapi,
     redis,
@@ -51,6 +52,7 @@ __all__ = [
     "dto",
     "exceptions",
     "health",
+    "http",
     "log",
     "openapi",
     "redis",
@@ -62,4 +64,4 @@ __all__ = [
     "worker",
 ]
 
-__version__ = "0.27.0"
+__version__ = "0.28.0"
