@@ -51,6 +51,7 @@ from starlite_saqlalchemy import (
     settings,
     sqlalchemy_plugin,
 )
+from starlite_saqlalchemy.constants import IS_LOCAL_ENVIRONMENT, IS_TEST_ENVIRONMENT
 from starlite_saqlalchemy.exceptions import HealthCheckConfigurationError
 from starlite_saqlalchemy.health import (
     AbstractHealthCheck,
@@ -132,7 +133,7 @@ class PluginConfig(BaseModel):
     Set the OpenAPI config object to
     [`AppConfig.openapi_config`][starlite.config.app.AppConfig.openapi_config].
     """
-    do_sentry: bool = True
+    do_sentry: bool | None = None
     """Configure sentry.
 
     Configure the application to initialize Sentry on startup. Adds a handler to
@@ -330,7 +331,12 @@ class ConfigureApp:
         Args:
             app_config: The Starlite application config object.
         """
-        if self.config.do_sentry:
+        do_sentry = (
+            self.config.do_sentry
+            if self.config.do_sentry is not None
+            else not (IS_LOCAL_ENVIRONMENT or IS_TEST_ENVIRONMENT)
+        )
+        if do_sentry:
             app_config.on_startup.append(sentry.configure)
 
     def configure_sqlalchemy_plugin(self, app_config: AppConfig) -> None:
